Package: DGEAR
Type: Package
Title: Differential Gene Expression Analysis with R
Version: 0.1.4
Authors@R: c(person("Koushik", "Bardhan", role = c("aut","cre","ctb"),email="koushikbardhan2000@gmail.com", comment = c(ORCID = "0009-0002-8846-8347")),
            person("Chiranjib", "Sarkar", role = c("aut","ths"),email="cschiranjib9@gmail.com", comment = c(ORCID = "0000-0003-1536-7449")))
Author: Koushik Bardhan [aut, cre, ctb]
    (<https://orcid.org/0009-0002-8846-8347>),
  Chiranjib Sarkar [aut, ths] (<https://orcid.org/0000-0003-1536-7449>)
Maintainer: Koushik Bardhan <koushikbardhan2000@gmail.com>
Description: Analyses gene expression data derived from experiments to detect differentially expressed genes by employing the concept of majority voting with five different statistical models. It includes functions for differential expression analysis, significance testing, etc. It simplifies the process of uncovering meaningful patterns and trends within gene expression data, aiding researchers in downstream analysis. Boyer, R.S., Moore, J.S. (1991) <doi:10.1007/978-94-011-3488-0_5>.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
Imports: DescTools
RoxygenNote: 7.3.1
Depends: R (>= 2.10)
Suggests: spelling, testthat (>= 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2024-06-26 20:08:54 UTC; koush
Repository: CRAN
Date/Publication: 2024-06-26 20:20:02 UTC
Language: en-US
Built: R 4.6.0; ; 2026-04-25 12:54:37 UTC; unix
