# Generated by roxygen2: do not edit by hand

export(DGEAR)
export(perform_anova)
export(perform_dunnett_test)
export(perform_h_test)
export(perform_t_test)
export(perform_wilcox_test)
export(read_and_preprocess_data)
importFrom(DescTools,DunnettTest)
importFrom(stats,na.omit)
importFrom(stats,oneway.test)
importFrom(stats,p.adjust)
importFrom(stats,pt)
importFrom(stats,sd)
importFrom(stats,t.test)
importFrom(stats,wilcox.test)
importFrom(utils,read.delim)
