% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{.prepare_data}
\alias{.prepare_data}
\title{Apply log2 normalisation if the data appear to be on a linear scale}
\usage{
.prepare_data(dataframe, con1, con2, exp1, exp2)
}
\arguments{
\item{dataframe}{Numeric data.frame.}

\item{con1, con2, exp1, exp2}{Column indices.}
}
\value{
A list with \code{dataframe} (possibly log2-transformed),
  \code{con}, \code{exp}, \code{con_m}, \code{exp_m}, \code{log2FC},
  and logical \code{log_transformed}.
}
\description{
Apply log2 normalisation if the data appear to be on a linear scale
}
\keyword{internal}
