% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{.resolve_symbols}
\alias{.resolve_symbols}
\title{Resolve gene symbols from row names or an optional annotation table}
\usage{
.resolve_symbols(dataframe, annot_df = NULL)
}
\arguments{
\item{dataframe}{Gene expression data.frame (rows = probes/genes).}

\item{annot_df}{Optional annotation data.frame with columns \code{ID} and
one of \code{Gene.Symbol} / \code{Gene.symbol}.  When \code{NULL} (the
default) row names of \code{dataframe} are used as gene identifiers.}
}
\value{
A character vector of gene symbols the same length as
  \code{nrow(dataframe)}.
}
\description{
Resolve gene symbols from row names or an optional annotation table
}
\keyword{internal}
